-- Settings.lua
-- Written by Habna


-- **v Load settings v**
function LoadSettings()
	settings = {};
	settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "HugeBagWindowSettings" );

	-- **v no setting found, so save it v**
	if settings == nil then
		WinLocX = Turbine.UI.Display.GetWidth() - edgePadding - WinWidth;
		WinLocY = Turbine.UI.Display.GetHeight() - edgePadding - WinHeight - 55;
		SaveSettings();
	end
	-- **^
	-- **v Load Settings v**
	if settings.Location == nil then
		settings.Location = {};
		settings.Location.X = Turbine.UI.Display.GetWidth() - edgePadding - WinWidth;
		settings.Location.Y = Turbine.UI.Display.GetHeight() - edgePadding - WinHeight - 55;
	else
		if settings.Location.X == nil then
			settings.Location.X = Turbine.UI.Display.GetWidth() - edgePadding - WinWidth;
		end
		if settings.Location.Y == nil then
			settings.Location.Y = Turbine.UI.Display.GetHeight() - edgePadding - WinHeight - 55;
		end
	end

	WinLocX = settings.Location.X;
	WinLocY = settings.Location.Y;

	if settings.Size == nil then
		settings.Size = {};
		settings.Size.W = WinWidth;
		settings.Size.H = WinHeight;
	else
		if settings.Size.W == nil then
			settings.Size.W = WinWidth;
		end
		if settings.Size.H == nil then
			settings.Size.H = WinHeight;
		end
	end

	WinWidth = settings.Size.W;
	WinHeight = settings.Size.H;

	-- **v Replace HugeBag if out of the screen on load v**
	if ( WinLocX + WinWidth ) > screenWidth then WinLocX = screenWidth - WinWidth end
	if ( WinLocY + WinHeight ) > screenHeight then WinLocY = screenHeight - WinHeight end
	-- **^

	if settings.BackColor == nil then
		settings.BackColor = {};
		settings.BackColor.A = bcAlpha;
		settings.BackColor.R = bcRed;
		settings.BackColor.G = bcGreen;
		settings.BackColor.B = bcBlue;
	else
		if settings.BackColor.A == nil then
			settings.BackColor.A = bcAlpha;
		end
		if settings.BackColor.R == nil then
			settings.BackColor.R = bcRed;
		end
		if settings.BackColor.G == nil then
			settings.BackColor.G = bcGreen;
		end
		if settings.BackColor.B == nil then
			settings.BackColor.B = bcBlue;
		end
	end

	bcAlpha = settings.BackColor.A;
	bcRed = settings.BackColor.R;
	bcGreen = settings.BackColor.G;
	bcBlue = settings.BackColor.B;

	if settings.Options == nil then
		settings.Options = {};
		settings.Options.StartVisible = StartVisible;
		settings.Options.ShowSlotsInfo = ShowSlotsInfo;
		settings.Options.HideWEsc = HideWEsc;
		settings.Options.LockPosition = LockPosition;
		settings.Options.LockSize = LockSize;
		settings.Options.ShowUsedInfo = ToggleUsed;
		settings.Options.ShowSkin = ShowSkin;
	else
		if settings.Options.StartVisible == nil then
			settings.Options.StartVisible = StartVisible;
		end
		if settings.Options.ShowSlotsInfo == nil then
			settings.Options.ShowSlotsInfo = ShowSlotsInfo;
		end
		if settings.Options.HideWEsc == nil then
			settings.Options.HideWEsc = HideWEsc;
		end
		if settings.Options.LockPosition == nil then
			settings.Options.LockPosition = LockPosition;
		end
		if settings.Options.LockSize == nil then
			settings.Options.LockSize = LockSize;
		end
		if settings.Options.ShowUsedInfo == nil then
			settings.Options.ShowUsedInfo = ToggleUsed;
		end
		if settings.Options.ShowSkin == nil then
			settings.Options.ShowSkin = ShowSkin;
		end
	end

	StartVisible = settings.Options.StartVisible;
	ShowSlotsInfo = settings.Options.ShowSlotsInfo;
	HideWEsc = settings.Options.HideWEsc;
	LockPosition = settings.Options.LockPosition;
	LockSize = settings.Options.LockSize;
	ToggleUsed = settings.Options.ShowUsedInfo;
	ShowSkin = settings.Options.ShowSkin;
	
	if settings.ButtonPos == nil then
		settings.ButtonPos = {};
		settings.ButtonPos.AtTop = ButtonAtTop;
		settings.ButtonPos.Sort = SortLeft;
		settings.ButtonPos.Search = SearchLeft;
		settings.ButtonPos.Merge = MergeLeft;
	else
		if settings.ButtonPos.AtTop == nil then
			settings.ButtonPos.AtTop = ButtonAtTop;
		end
		if settings.ButtonPos.Sort == nil then
			settings.ButtonPos.Sort = SortLeft;
		end
		if settings.ButtonPos.Search == nil then
			settings.ButtonPos.Search = SearchLeft;
		end
		if settings.ButtonPos.Merge == nil then
			settings.ButtonPos.Merge = MergeLeft;
		end
	end

	ButtonAtTop = settings.ButtonPos.AtTop;
	SortLeft = settings.ButtonPos.Sort;
	SearchLeft = settings.ButtonPos.Search;
	MergeLeft = settings.ButtonPos.Merge;

	if settings.Version == nil then
		settings.Version = Version;
	end

	settings.Version = Version;
	-- **^
end
-- **^
-- **v Save settings v**
function SaveSettings()
	settings = {};
	settings.Version = Version;

	settings.Location = {};
	settings.Location.X = WinLocX;
	settings.Location.Y = WinLocY;

	settings.Size = {};
	settings.Size.W = WinWidth;
	settings.Size.H = WinHeight;

	settings.Options = {};
	settings.Options.StartVisible = StartVisible;
	settings.Options.ShowSlotsInfo = ShowSlotsInfo;
	settings.Options.ShowUsedInfo = ToggleUsed;
	settings.Options.HideWEsc = HideWEsc;
	settings.Options.LockPosition = LockPosition;
	settings.Options.LockSize = LockSize;
	settings.Options.ShowSkin = ShowSkin;

	settings.BackColor = {};
	settings.BackColor.A = bcAlpha;
	settings.BackColor.R = bcRed;
	settings.BackColor.G = bcGreen;
	settings.BackColor.B = bcBlue;

	settings.ButtonPos = {};
	settings.ButtonPos.AtTop = ButtonAtTop;
	settings.ButtonPos.Sort = SortLeft;
	settings.ButtonPos.Search = SearchLeft;
	settings.ButtonPos.Merge = MergeLeft;

	Turbine.PluginData.Save( Turbine.DataScope.Character, "HugeBagWindowSettings", settings );

	Modesettings = {};
	Modesettings.Widget = Widget;
	Turbine.PluginData.Save( Turbine.DataScope.Character, "HugeBagMode", Modesettings );
end
-- **^
-- **v Reset Location and Size Settings v**
function ResetLSSettings()
	WinWidth, WinHeight = 460, 300;
	frmMain:SetSize( WinWidth, WinHeight );
	frmMain:SetPosition( Turbine.UI.Display.GetWidth() - edgePadding - WinWidth, Turbine.UI.Display.GetHeight() - edgePadding - WinHeight - 55 );
	WinLocX, WinLocY = frmMain:GetPosition();
	SaveSettings();
	frmMain:SetVisible( true );
	frmMain:PerformLayout();
	Turbine.Shell.WriteLine( "HugeBag: My location and size was set back to default" );
end
-- **^
-- **v Reset All Settings v**
function ResetSettings()
	StartVisible = true;
	ShowSlotsInfo = true;
	ToggleUsed = false;
	HideWEsc = true;
	LockPosition = true;
	LockHugeBagPosition();
	LockSize = true;
	LockHugeBagSize();
	Widget = Widget;
	WinWidth, WinHeight = 460, 300;
	frmMain:SetSize( WinWidth, WinHeight );
	frmMain:SetPosition( Turbine.UI.Display.GetWidth() - edgePadding - WinWidth, Turbine.UI.Display.GetHeight() - edgePadding - WinHeight - 55 );
	WinLocX, WinLocY = frmMain:GetPosition()
	bcAlpha, bcRed, bcGreen, bcBlue = 1, 0, 0, 0;
	frmMain.itemListBox:SetBackColor( Turbine.UI.Color( bcAlpha, bcRed, bcGreen, bcBlue ) );
	frmMain:SetVisible( true );
	frmMain:PerformLayout();
	frmMain:PrintTitle();
	ShowSkin = false;
	ToggleSkin();
	SaveSettings();
	Turbine.Shell.WriteLine( "HugeBag: All my settings was set back to default" );
end
-- **^